package cn.com.infosec.x509;

import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1InputStream;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DERBitString;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.x509.AlgorithmIdentifier;
import cn.com.infosec.asn1.x509.SubjectPublicKeyInfo;
import cn.com.infosec.asn1.x509.TBSCertificateStructure;
import cn.com.infosec.asn1.x509.Time;
import cn.com.infosec.asn1.x509.V1TBSCertificateGenerator;
import cn.com.infosec.asn1.x509.X509CertificateStructure;
import cn.com.infosec.asn1.x509.X509Name;
import cn.com.infosec.jce.X509Principal;
import cn.com.infosec.jce.provider.X509CertificateObject;
import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.math.BigInteger;
import java.security.GeneralSecurityException;
import java.security.InvalidKeyException;
import java.security.NoSuchProviderException;
import java.security.PrivateKey;
import java.security.PublicKey;
import java.security.SecureRandom;
import java.security.SignatureException;
import java.security.cert.CertificateParsingException;
import java.security.cert.X509Certificate;
import java.util.Date;
import java.util.Iterator;
import javax.security.auth.x500.X500Principal;

public class X509V1CertificateGenerator {
   private V1TBSCertificateGenerator tbsGen;
   private DERObjectIdentifier sigOID;
   private AlgorithmIdentifier sigAlgId;
   private String signatureAlgorithm;

   public X509V1CertificateGenerator() {
      X509V1CertificateGenerator var10000 = this;
      super();
      V1TBSCertificateGenerator var1;
      var1 = new V1TBSCertificateGenerator.<init>();
      var10000.tbsGen = var1;
   }

   private X509Certificate generateJcaObject(TBSCertificateStructure tbsCert, byte[] signature) {
      ASN1EncodableVector var3;
      ASN1EncodableVector var10000 = var3 = new ASN1EncodableVector;
      var3.<init>();
      var3.add(tbsCert);
      var10000.add(this.sigAlgId);
      var10000.add(new DERBitString(signature));

      try {
         return new X509CertificateObject(new X509CertificateStructure(new DERSequence(var3)));
      } catch (CertificateParsingException var4) {
         throw new ExtCertificateEncodingException("exception producing certificate object", var4);
      }
   }

   public void reset() {
      X509V1CertificateGenerator var10000 = this;
      V1TBSCertificateGenerator var1;
      var1 = new V1TBSCertificateGenerator.<init>();
      var10000.tbsGen = var1;
   }

   public void setSerialNumber(BigInteger serialNumber) {
      if (serialNumber.compareTo(BigInteger.ZERO) > 0) {
         this.tbsGen.setSerialNumber(new DERInteger(serialNumber));
      } else {
         throw new IllegalArgumentException("serial number must be a positive integer");
      }
   }

   public void setIssuerDN(X500Principal issuer) {
      try {
         this.tbsGen.setIssuer(new X509Principal(issuer.getEncoded()));
      } catch (IOException var2) {
         throw new IllegalArgumentException("can't process principal: " + var2);
      }
   }

   public void setIssuerDN(X509Name issuer) {
      this.tbsGen.setIssuer(issuer);
   }

   public void setNotBefore(Date date) {
      this.tbsGen.setStartDate(new Time(date));
   }

   public void setNotAfter(Date date) {
      this.tbsGen.setEndDate(new Time(date));
   }

   public void setSubjectDN(X500Principal subject) {
      try {
         this.tbsGen.setSubject(new X509Principal(subject.getEncoded()));
      } catch (IOException var2) {
         throw new IllegalArgumentException("can't process principal: " + var2);
      }
   }

   public void setSubjectDN(X509Name subject) {
      this.tbsGen.setSubject(subject);
   }

   public void setPublicKey(PublicKey key) {
      try {
         this.tbsGen.setSubjectPublicKeyInfo(new SubjectPublicKeyInfo((ASN1Sequence)(new ASN1InputStream(new ByteArrayInputStream(key.getEncoded()))).readObject()));
      } catch (Exception var2) {
         throw new IllegalArgumentException("unable to process key - " + var2.toString());
      }
   }

   public void setSignatureAlgorithm(String signatureAlgorithm) {
      X509V1CertificateGenerator var10000 = this;
      String var10002 = this.signatureAlgorithm = signatureAlgorithm;

      boolean var10001;
      DERObjectIdentifier var6;
      try {
         var6 = X509Util.getAlgorithmOID(var10002);
      } catch (Exception var4) {
         var10001 = false;
         throw new IllegalArgumentException("Unknown signature type requested");
      }

      DERObjectIdentifier var2 = var6;

      String var10003;
      try {
         var10003 = signatureAlgorithm;
         this.sigOID = var2;
      } catch (Exception var3) {
         var10001 = false;
         throw new IllegalArgumentException("Unknown signature type requested");
      }

      AlgorithmIdentifier var5;
      this.sigAlgId = var5 = X509Util.getSigAlgID(var6, var10003);
      var10000.tbsGen.setSignature(var5);
   }

   /** @deprecated */
   public X509Certificate generateX509Certificate(PrivateKey key) {
      try {
         return this.generateX509Certificate(key, "INFOSEC", (SecureRandom)null);
      } catch (NoSuchProviderException var2) {
         throw new SecurityException("BC provider not installed!");
      }
   }

   /** @deprecated */
   public X509Certificate generateX509Certificate(PrivateKey key, SecureRandom random) {
      try {
         return this.generateX509Certificate(key, "INFOSEC", random);
      } catch (NoSuchProviderException var3) {
         throw new SecurityException("BC provider not installed!");
      }
   }

   /** @deprecated */
   public X509Certificate generateX509Certificate(PrivateKey key, String provider) {
      return this.generateX509Certificate(key, provider, (SecureRandom)null);
   }

   /** @deprecated */
   public X509Certificate generateX509Certificate(PrivateKey key, String provider, SecureRandom random) {
      try {
         return this.generate(key, provider, random);
      } catch (NoSuchProviderException var4) {
         throw var4;
      } catch (SignatureException var5) {
         throw var5;
      } catch (InvalidKeyException var6) {
         throw var6;
      } catch (GeneralSecurityException var7) {
         throw new SecurityException("exception: " + var7);
      }
   }

   public X509Certificate generate(PrivateKey key) {
      return this.generate(key, (SecureRandom)null);
   }

   public X509Certificate generate(PrivateKey param1, SecureRandom param2) {
      // $FF: Couldn't be decompiled
   }

   public X509Certificate generate(PrivateKey key, String provider) {
      return this.generate(key, provider, (SecureRandom)null);
   }

   public X509Certificate generate(PrivateKey param1, String param2, SecureRandom param3) {
      // $FF: Couldn't be decompiled
   }

   public Iterator getSignatureAlgNames() {
      return X509Util.getAlgNames();
   }
}
